@@ -178,8 +178,8 @@ class Converter:
             attachments=cls.attachment_models_to_attachment_put_models(test_result.attachments),
             duration_in_ms=test_result.duration_in_ms,
             step_comments=test_result.step_comments,
-            setup_results=test_result.setup_results,
-            teardown_results=test_result.teardown_results,
+            # setup_results=test_result.setup_results,
+            # teardown_results=test_result.teardown_results,
             message=test_result.message,
             trace=test_result.traces)
 
